#
# spec file for package python-hvplot
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-hvplot
Version:        0.6.0
Release:        1.2
Summary:        High-level plotting API for the PyData ecosystem built on HoloViews
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/pyviz/hvplot
Source0:        https://files.pythonhosted.org/packages/source/h/hvplot/hvplot-%{version}.tar.gz
Source100:      python-hvplot-rpmlintrc
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-bokeh >= 1.0.0
Requires:       python-holoviews >= 1.11.0
Requires:       python-pandas
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-Pillow
Recommends:     python-dask
Recommends:     python-datashader >= 0.6.5
Recommends:     python-geopandas
Recommends:     python-geoviews
Recommends:     python-intake
Recommends:     python-intake-parquet
Recommends:     python-nbsite >= 0.5.1
Recommends:     python-networkx
Recommends:     python-notebook >= 5.4
Recommends:     python-param >= 1.6.1
Recommends:     python-phantomjs
Recommends:     python-scipy
Recommends:     python-selenium
Recommends:     python-streamz >= 0.3.0
Recommends:     python-xarray
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module bokeh >= 1.0.0}
BuildRequires:  %{python_module coveralls}
BuildRequires:  %{python_module dask}
BuildRequires:  %{python_module datashader >= 0.6.5}
BuildRequires:  %{python_module flake8}
BuildRequires:  %{python_module holoviews >= 1.11.0}
BuildRequires:  %{python_module nbsmoke >= 0.2.0}
BuildRequires:  %{python_module networkx}
BuildRequires:  %{python_module notebook >= 5.4}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module param >= 1.6.1}
BuildRequires:  %{python_module parameterized}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module selenium}
BuildRequires:  %{python_module streamz >= 0.3.0}
BuildRequires:  %{python_module xarray}
# /SECTION
%python_subpackages

%description
hvPlot provides a high-level plotting API built on HoloViews that
provides a general and consistent API for plotting data in various
formats from the PyData ecosystem. hvPlot can integrate neatly with
individual PyData libraries if an extension mechanism for the native
plot APIs is offered, or it can be used as a standalone component.

%prep
%setup -q -n hvplot-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/hvplot
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# tests require a network connection
# %%check
# %%python_expand nosetests-%%{$python_bin_suffix} -v hvplot

%post
%python_install_alternative hvplot

%postun
%python_uninstall_alternative hvplot

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/hvplot
%{python_sitelib}/*

%changelog
* Wed Jun 24 2020 Todd R <toddrme2178@gmail.com>
- Update to version 0.6.0
  + New features:
  * Added (a start to) a reference gallery (#302, #357, #359, #360, #361)
  * Improved save and show utilities (#451)
  * Improved compatibility for tab completion (#411)
  * Major performance enhancement with Datashader in some cases (#465)
  * Add support for cuDF (#454, #466)
  * Support by argument for categorical aggregation (#461)
  * Support color_key alias (#446, #458)
  * Support spatialpandas for large sets of polygons (#459)
  * Add fontscale keyword (#397)
  * Added heat and trees example to topics (#378)
  + Bug fixes and compatibility:
  * Fixed 'title_format' deprecation warning (#428)
  * Fix networkx documentation (#476)
  * Avoid sorting overlays, to make color cycles consistent (#475)
  * Replaced sphinx_pyviz_theme with sphinx_holoviz_theme (#366)
  * Removed references to pyviz (#373)
  * Update environment.yml (#356)
  * Misc bugfixes/updates (#387, #403, #408, #439, #447, #448, #449, #450, #452, #453, #456, #467)
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Apr 15 2020 Paolo Stivanin <info@paolostivanin.com>
- Remove nose dep since we can't run the tests
* Thu Oct 24 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.5.2
  * Stop swallowing groupby widgets when passing widgets
  * Exposing plot at top level
  * Allow tiles to be objects as well as strings
  * Coastline sets geo=True by default
  * Fix multi z
  * Don't count by if subplots
  * Adding a max size for checking symmetry
  * Reading over docs and adding widgets and timeseries sections
  * Fixing up row/col to make behavior match groupby/by
  * Allow more widget options
  * Allow the source Dataset to flow through to Histogram elements
  * Add indexes to table output by default
  * Made hvplot API dynamic by accepting parameter/widget instances
  * Entrypoints for pandas >=0.25
  * Fix stats plots ordering
  * Make glasbey_category10 the default categorical colormap
  * Fixing proj_to_cartopy for pyproj <2.2 and adding test
  * Determine whether data is divergent and use a RdBu colormap / center …
  * Fixed bug when providing empty edgelist
  * Allow constructing geo-RGB
  * Derived datetime for tabular data
  * Fixing color order should match node order
  * Adding the ability to get index on hover
  * Fixing lim should be used as range when datashading
  * Allow datashade/rasterize even when c is same as x or y
  * If datashade=True then hover should be false by default
  * If cmap is a dict, just pass it through
  * Fix 'where' parameter in .hvplot().step()
  * Alternative implementation to aspect handling
  * Allow cmap to be list
  * Adding derived datatime for xarray
  * Using attrs to set default x and y for gridded outputs
  * Fix label for xr.Dataset
  * Use default opts if set, changing default numeric cmap
  * Sort by date by default when using pandas objects
  * Improved handling of datashader aggregator
  * Add coastline/tiles options
  * Label from attributes
  * Only include numeric columns by default if available in data
  * Handle heatmap rendering as array
  * Add support for geo hexbin
  * Consistently handle dim mappings
  * Fixed handling of logz
  * Trying to do more sensible defaults for 2D xarrays
  * Allow list types for xlim,ylim tuples
  * Expose responsive plot options
  * Consistently warn if plot type does not support geo
  * Plot vectorfield
  * Add clabel
  * Let holoviews set defaults for points
  * Changed ioam pinning to pyviz
  * Add errorbars
  * Add min_count option for hexbin plots.
  * Make xsampling/ysampling -> x_sampling/y_sampling
  * If line or scatter, warn that it will not project
* Mon Jun  3 2019 Todd R <toddrme2178@gmail.com>
- Fix jupyter dependencies.
* Tue Jan  8 2019 Todd R <toddrme2178@gmail.com>
- initial version
